@@ -14,8 +14,8 @@ except NameError:
 
 
 if sys.version_info[0] == 2:
-    from StringIO import StringIO as BytesIO
     from StringIO import StringIO
+    from StringIO import StringIO as BytesIO
 
 else:
     from io import BytesIO, StringIO
@@ -105,7 +105,7 @@ def imp_walk(name):
     raise ImportError("No module named %s" % (name,))
 
 
-cookie_re = re.compile(br"coding[:=]\s*([-\w.]+)")
+cookie_re = re.compile(rb"coding[:=]\s*([-\w.]+)")
 if sys.version_info[0] == 2:
     default_encoding = "ascii"
 else:
